Synchronization
===============

Phase-locked loops
------------------

.. python-apigen-group:: pll

Phase error detectors
---------------------

.. python-apigen-group:: synchronization-ped

Amplitude control loops
-----------------------

.. python-apigen-group:: synchronization-amplitude
